# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class OriginType(str, Enum):
    """
    OriginType
    """

    """
    allowed enum values
    """
    COLLABORATOR = 'Collaborator'
    REPOSITORY = 'Repository'
    REPOSITORYGROUP = 'RepositoryGroup'
    SERVER = 'Server'
    PERSONALACCESSTOKEN = 'PersonalAccessToken'
    THIRDPARTYAPP = 'ThirdPartyApp'
    PACKAGE = 'Package'
    KNOWLEDGEPAGE = 'KnowledgePage'
    TICKETINGSYSTEM = 'TicketingSystem'
    WEBAPPLICATION = 'WebApplication'
    FILESHARINGSYSTEM = 'FileSharingSystem'
    JOB = 'Job'
    JENKINSSERVER = 'JenkinsServer'
    HOST = 'Host'
    SHAREDFILE = 'SharedFile'
    ARTIFACTFILE = 'ArtifactFile'
    CLOUDRESOURCE = 'CloudResource'
    UNKNOWN = 'Unknown'
    MESSAGINGAPPCHANNEL = 'MessagingAppChannel'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of OriginType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SdlcAssetType(str, Enum):
    """
    SdlcAssetType
    """

    """
    allowed enum values
    """
    GITHUBENTERPRISESERVER = 'GitHubEnterpriseServer'
    GITLAB = 'GitLab'
    BITBUCKET = 'Bitbucket'
    GITHUBCLOUD = 'GitHubCloud'
    BITBUCKETCLOUD = 'BitbucketCloud'
    JENKINS = 'Jenkins'
    AZUREDEVOPSSERVICES = 'AzureDevopsServices'
    AZUREDEVOPSSERVER = 'AzureDevopsServer'
    SHIFTLEFT = 'ShiftLeft'
    GITHUBACTIONS = 'GitHubActions'
    GITLABCI = 'GitLabCi'
    BITBUCKETPIPELINES = 'BitbucketPipelines'
    AZUREDEVOPSPIPELINES = 'AzureDevopsPipelines'
    DRONE = 'Drone'
    ARTIFACTORY = 'Artifactory'
    GITLABCLOUD = 'GitLabCloud'
    UNKNOWNSCM = 'UnknownScm'
    GERRIT = 'Gerrit'
    GITHUBPACKAGES = 'GitHubPackages'
    BAMBOO = 'Bamboo'
    GITLABPACKAGES = 'GitLabPackages'
    AZUREDEVOPSPACKAGES = 'AzureDevOpsPackages'
    HARBOR = 'Harbor'
    DOCKERHUB = 'DockerHub'
    UNKNOWNCONTAINERREGISTRY = 'UnknownContainerRegistry'
    GOOGLECONTAINERREGISTRY = 'GoogleContainerRegistry'
    CIRCLECI = 'CircleCi'
    AMAZONELASTICCONTAINERREGISTRY = 'AmazonElasticContainerRegistry'
    TEAMCITY = 'TeamCity'
    TEAMFORGE = 'TeamForge'
    KUBERNETES = 'Kubernetes'
    MANAGEDKUBERNETES = 'ManagedKubernetes'
    GITHUBCONTAINERREGISTRY = 'GithubContainerRegistry'
    CROWDSTRIKE = 'CrowdStrike'
    ORACLECONTAINERREGISTRY = 'OracleContainerRegistry'
    MIRANTIS = 'Mirantis'
    SONATYPENEXUS = 'SonatypeNexus'
    OPENSHIFT = 'Openshift'
    GOOGLEARTIFACTREGISTRY = 'GoogleArtifactRegistry'
    IBMCLOUD = 'IbmCloud'
    AZURECONTAINERREGISTRY = 'AzureContainerRegistry'
    QUAYIO = 'QuayIo'
    HELIXCORE = 'HelixCore'
    APACHEAIRFLOW = 'ApacheAirFlow'
    AMAZONSAGEMAKER = 'AmazonSageMaker'
    VERACODE = 'Veracode'
    CODECOMMIT = 'CodeCommit'
    WIZ = 'Wiz'
    CONFLUENCE = 'Confluence'
    AMAZONELASTICKUBERNETESSERVICE = 'AmazonElasticKubernetesService'
    AZUREKUBERNETESSERVICE = 'AzureKubernetesService'
    SNYK = 'Snyk'
    AZUREBOARDS = 'AzureBoards'
    BLACKDUCK = 'BlackDuck'
    CHECKMARXSAST = 'CheckmarxSast'
    CHECKMARXSCA = 'CheckmarxSca'
    SERVICENOW = 'ServiceNow'
    BURPSUITE = 'Burpsuite'
    JIRASECRETSCANNING = 'JiraSecretScanning'
    COVERITY = 'Coverity'
    SHORTCUT = 'Shortcut'
    CHECKMARXONE = 'CheckmarxOne'
    QUALYS = 'Qualys'
    INVICTI = 'Invicti'
    ENDORLABS = 'EndorLabs'
    FORTIFY = 'Fortify'
    PRISMACLOUD = 'PrismaCloud'
    ORCA = 'Orca'
    HCLAPPSCAN = 'HclAppScan'
    INSIGHTAPPSEC = 'InsightAppSec'
    STACKHAWK = 'StackHawk'
    GOOGLEKUBERNETESENGINE = 'GoogleKubernetesEngine'
    NOWSECURE = 'NowSecure'
    ONAPSIS = 'Onapsis'
    BRIGHTSECURITY = 'BrightSecurity'
    QUOKKAQMAST = 'QuokkaQMast'
    CONTRASTSECURITY = 'ContrastSecurity'
    LACEWORK = 'Lacework'
    SPINNAKER = 'Spinnaker'
    XRAY = 'Xray'
    MANUALUPLOAD = 'ManualUpload'
    SLACK = 'Slack'
    WEBHOOK = 'Webhook'
    MICROSOFTTEAMS = 'MicrosoftTeams'
    TORQ = 'Torq'
    AQUA = 'Aqua'
    GITHUBCLOUDPUBLIC = 'GitHubCloudPublic'
    SERVICENOWSECRETSCANNING = 'ServiceNowSecretScanning'
    JIRA = 'Jira'
    MENDSAST = 'MendSast'
    MENDSCA = 'MendSca'
    SEMGREP = 'Semgrep'
    SONARCLOUD = 'SonarCloud'
    SONARQUBE = 'SonarQube'
    SONATYPE = 'Sonatype'
    QUAYSERVER = 'QuayServer'
    OPENSHIFTCONTAINERREGISTRY = 'OpenShiftContainerRegistry'
    REDHATADVANCEDCLUSTERSECURITY = 'RedHatAdvancedClusterSecurity'
    QUALYSVMDR = 'QualysVmdr'
    TENABLE = 'Tenable'
    NONAME = 'Noname'
    SHAREPOINT = 'SharePoint'
    TRACEABLE = 'Traceable'
    OLIGO = 'Oligo'
    SLACKAPPLICATIONSCANNING = 'SlackApplicationScanning'
    AMAZONINSPECTOR = 'AmazonInspector'
    AMAZONSECURITYHUB = 'AmazonSecurityHub'
    UPWIND = 'Upwind'
    MICROSOFTTEAMSSCANNING = 'MicrosoftTeamsScanning'
    LEGITSCA = 'LegitSca'
    ACUNETIX = 'Acunetix'
    MEND = 'Mend'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SdlcAssetType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DiscoveryConnectionEvidenceType(str, Enum):
    """
    DiscoveryConnectionEvidenceType
    """

    """
    allowed enum values
    """
    UNKNOWN = 'Unknown'
    FILE = 'File'
    WEBHOOK = 'Webhook'
    CONFIG = 'Config'
    JOBCONFIG = 'JobConfig'
    THIRDPARTYAPP = 'ThirdPartyApp'
    ORGANIZATIONWEBHOOK = 'OrganizationWebhook'
    CORRELATEDARTIFACT = 'CorrelatedArtifact'
    GITLABREPOSITORYTOREGISTRY = 'GitLabRepositoryToRegistry'
    MANUALCORRELATION = 'ManualCorrelation'
    LLMBASEDCORRELATION = 'LlmBasedCorrelation'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DiscoveryConnectionEvidenceType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.sdlc_asset_graph_link_dto import SdlcAssetGraphLinkDto

class TestSdlcAssetGraphLinkDto(unittest.TestCase):
    """SdlcAssetGraphLinkDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SdlcAssetGraphLinkDto:
        """Test SdlcAssetGraphLinkDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SdlcAssetGraphLinkDto`
        """
        model = SdlcAssetGraphLinkDto()
        if include_optional:
            return SdlcAssetGraphLinkDto(
                source_id = '',
                source_type = 'Unknown',
                target_id = '',
                target_type = 'Unknown',
                evidences = legit_api_client.models.sdlc_asset_graph_link_dto_evidences.SdlcAssetGraphLinkDto_evidences(
                    unknown = [
                        ''
                        ], 
                    file = [
                        ''
                        ], 
                    webhook = [
                        ''
                        ], 
                    config = [
                        ''
                        ], 
                    job_config = [
                        ''
                        ], 
                    third_party_app = [
                        ''
                        ], 
                    organization_webhook = [
                        ''
                        ], 
                    correlated_artifact = [
                        ''
                        ], 
                    git_lab_repository_to_registry = [
                        ''
                        ], 
                    manual_correlation = [
                        ''
                        ], 
                    llm_based_correlation = [
                        ''
                        ], )
            )
        else:
            return SdlcAssetGraphLinkDto(
        )
        """

    def testSdlcAssetGraphLinkDto(self):
        """Test SdlcAssetGraphLinkDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
